import { ApiAction, ApiActionPage } from '../../model/baseModel';
import { Api, genAction, genActionPage } from '../system';
import { defHttp } from '/@/utils/http/axios';
import { MES_ROUTE, RouteData } from '../model/router';
import { mesApi } from './mesApi';
import { useUserStore } from '/@/store/modules/user';
import { RoutePageListGetResultModel, RoutelistPageParams } from '../model/mesModel';

/*
 * 获取工艺路线列表
 */
export function getRouteData(route_code: string) {
  const params = genAction('', route_code);
  return getApi(params);
}
async function getApi(params: ApiAction<string>) {
  const data = await defHttp.post<ApiAction<RouteData>>(
    {
      url: mesApi.GetRouteData,
      params,
    },
    {
      errorMessageMode: 'modal',
      isTransformResponse: false,
    },
  );
  return data;
}

//保存
export const SaveRouteData = async (params: RouteData) => {
  const data = await defHttp.post(
    { url: mesApi.SaveRouteData, params: genAction('', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};
export const SaveRoute = async (params: MES_ROUTE) => {
  params.CREATE_USER = useUserStore().getUserInfo.userId as string;
  params.UPDATE_USER = useUserStore().getUserInfo.userId as string;
  const data = await defHttp.post(
    { url: mesApi.SaveRoute, params: genAction('MES_ROUTE', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/*
 * 获取工艺路线分页列表
 */
export const getRouteListByPage = async (params: RoutelistPageParams) => {
  let sqlcmd = '';
  if (params?.IS_ACTIVE != undefined && params?.IS_ACTIVE != '') {
    sqlcmd += " And IS_ACTIVE = '" + params?.IS_ACTIVE + "'";
  }
  if (params?.ROT_CODE != undefined && params?.ROT_CODE != '') {
    sqlcmd += "And ROT_CODE like '%" + params?.ROT_CODE + "%'";
  }
  if (params?.ROT_NAME != undefined && params?.ROT_NAME != '') {
    sqlcmd += "And ROT_NAME like '%" + params?.ROT_NAME + "%'";
  }
  const rParams = genActionPage('MES_ROUTE', sqlcmd, params.page, params.pageSize);
  return getRoleListByPageAsync(rParams);
};
async function getRoleListByPageAsync(params: ApiActionPage) {
  const data = await defHttp.post<ApiActionPage>(
    { url: Api.EntityPageList, params },
    {
      isTransformResponse: false,
    },
  );
  const model: RoutePageListGetResultModel = {
    items: data.Data.data,
    total: data.Data.totals,
  };
  return model;
}

/*
 * 删除工艺路线
 */
export const DeleteRoute = async (params: string) => {
  const usParams = genAction('MES_ROUTE', params);
  return await defHttp.post(
    { url: mesApi.DeleteRoute, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};

export const setRouteStatus = (params: MES_ROUTE) =>
  defHttp.post(
    { url: Api.UpdateEntity, params: genAction('MES_ROUTE', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
